package LeonMP3Encoder.Encoder;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import LeonMP3Encoder.ComposantsGraphiques.*;
import LeonMP3Encoder.Interface.*;
import LeonMP3Encoder.Affichage.*;

public class LeonMP3Encoder extends JFrame
{
	private JMenuItem nouveau;
	private JMenuItem remove;
	private JMenuItem vider;
	private JMenuItem quit;
	private JMenuItem comp;
	private JMenuItem decomp;
	private JMenuItem help;
	private JMenuItem apropos;

	private listeJPanel ljp;
	private barJPanel bjp;
	private optionJPanel ojp;
	
	public LeonMP3Encoder( String [] args )
	{
		this();
		loadArgs( args );
	}
	
	public LeonMP3Encoder( )
	{
		init();
		initBar();
		initInterface();
		end();
		verifBloquer();
	}	
	
	public void init()
	{
		try {UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());} 
		catch (Exception e) { e.printStackTrace();}
		setTitle(Evenements.SoftName);	
		
		String path = this.getClass().getResource(".").getPath();
		Evenements.setPath(path.substring(1,path.length()).replace('/', '\\').replaceAll("%20", " "));		
	}
	
	public void initBar()
	{
		nouveau = new JMenuItem (Evenements.AddString, 'N');		
		remove 	= new JMenuItem (Evenements.RemoveString, 'D');				
		vider 	= new JMenuItem (Evenements.ClearString, 'D');		
		quit 	= new JMenuItem (Evenements.ExitString, 'Q');	
		comp 	= new JMenuItem (Evenements.CompressString, 'D');		
		decomp 	= new JMenuItem (Evenements.UncompressString, 'Q');		
		help 	= new JMenuItem (Evenements.HelpString, 'A');
		apropos = new JMenuItem (Evenements.AboutString, 'A');	
		
		nouveau.addActionListener( new ActionListener (){public void actionPerformed (ActionEvent ev ){addFile( Evenements.chooseFiles() );}});
		vider.addActionListener( new ActionListener (){public void actionPerformed (ActionEvent ev ){clear();}});
		remove.addActionListener( new ActionListener (){public void actionPerformed (ActionEvent ev ){removeSelected();}});				
		quit.addActionListener( new ActionListener (){public void actionPerformed (ActionEvent ev ){System.exit(0);}});
		comp.addActionListener( new ActionListener (){public void actionPerformed (ActionEvent ev ){compressFiles();}});				
		decomp.addActionListener( new ActionListener (){public void actionPerformed (ActionEvent ev ){uncompressFiles();}});

		help.addActionListener( new ActionListener (){public void actionPerformed (ActionEvent ev ){javax.swing.JOptionPane.showMessageDialog(null,Evenements.HelpMenu,Evenements.HelpTitle,JOptionPane.PLAIN_MESSAGE);}});
		apropos.addActionListener( new ActionListener ()
		{
			public void actionPerformed (ActionEvent ev )
			{
				
				javax.swing.JOptionPane.showMessageDialog(null,Evenements.AboutMenu,Evenements.AboutTitle,JOptionPane.PLAIN_MESSAGE);
			}
		});		
		
		JMenu menuFichier = new JMenu(Evenements.FileSubString);	
		JMenu menuAction = new JMenu(Evenements.ActionSubString);			
		JMenu menuApropos = new JMenu(Evenements.HelpSubString);	
		
		menuFichier.add ( nouveau 	);
		menuFichier.add ( remove 	);		
		menuFichier.add ( vider 	);		
		menuFichier.add ( new JSeparator() );			
		menuFichier.add ( quit	);	
		menuAction.add ( comp );
		menuAction.add ( decomp	);		
		menuApropos.add ( help	 	);	
		menuApropos.add ( apropos 	);	

		JMenuBar barreMenu = new JMenuBar();		
		barreMenu.add ( menuFichier );	
		barreMenu.add ( menuAction );			
		barreMenu.add ( menuApropos );	
		setJMenuBar (barreMenu);		
	}		
	
	public void initInterface()
	{
		ljp = new listeJPanel();
		bjp = new barJPanel(this);
		ojp = new optionJPanel();
		
		add(bjp,BorderLayout.NORTH);		
		add(new JScrollPane(ljp.get()),BorderLayout.CENTER);
		add(ojp,BorderLayout.SOUTH);			
	}
	
	public void loadArgs( String [] args )
	{
		ljp.add( args );
		Evenements.setUrl(args[0].substring(0,args[0].lastIndexOf('\\')));
		verifBloquer();
	}
	
	public void end()
	{
		setIconImage(new LeonImage(Toolkit.getDefaultToolkit().getImage("/"+Evenements.getPath()+"../../../Imgs/icon.png")).getImage());
		setSize(640,480);
		setLocationRelativeTo(getParent());
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setResizable(true);
		setVisible (true);		
	}
	
	public void addFile( String[] liste)
	{
		ljp.add( liste );
		verifBloquer();
	}
	
	public void removeSelected()
	{
		ljp.removeSelected(); 
		verifBloquer();
	}
	
	public void clear()
	{
		ljp.clear();
		verifBloquer();
	}
	
	private void compress(boolean mp3)
	{
		String [] fichiers 	= ljp.getListeFichier();
		String [] chemins 	= ljp.getListeChemin();
		String [] types 	= ljp.getListeType();
		String cmd ="";
		
		try 
		{
			for(int i=0;i<fichiers.length;i++)
			{
				if(i!=0)
					cmd += ",,,separator,,,";
					cmd += ",,,quote,,,"+Evenements.getPath()+"..\\..\\..\\Rsc\\lame.exe"+",,,quote,,,"+' '+",,,quote,,,"+chemins[i]+"\\"+fichiers[i]+"."+types[i]+",,,quote,,,"+" "+",,,quote,,,"+ojp.getDir()+fichiers[i];
					
					if(mp3)
						cmd +=".mp3,,,quote,,,"+" "+ojp.getOptions(true);
					else	
						cmd += ".wav,,,quote,,, "+ojp.getOptions(false)+" --decode ";						
			}
			
			cmd = cmd.replace('/','\\');		
			Runtime r = Runtime.getRuntime();

			r.exec("java -cp \""+Evenements.getPath()+"../../\" LeonMP3Encoder.Encoder.Encoder "+cmd);		
		}
		catch(Exception e)
		{
			System.out.println("erreur d'execution " + cmd + e.toString());
		} 
	}
	
	public void compressFiles()
	{
		compress(true);
	}
	
	public void uncompressFiles()
	{	
		compress(false);
	}	
	
	public void verifBloquer()
	{
		if(ljp.getRowCount() > 0)
		{
			bloquer(barJPanel.BUTTON_COMPRESS, false);
			bloquer(barJPanel.BUTTON_UNCOMPRESS, false);
			bloquer(barJPanel.BUTTON_CLEAR, false);
			bloquer(barJPanel.BUTTON_REMOVE, false);
		}
		else
		{
			bloquer(barJPanel.BUTTON_COMPRESS, true);
			bloquer(barJPanel.BUTTON_UNCOMPRESS, true);
			bloquer(barJPanel.BUTTON_CLEAR, true);
			bloquer(barJPanel.BUTTON_REMOVE, true);
		}
	}
	
	public void bloquer(int composant, boolean etat)
	{
		if( composant == barJPanel.BUTTON_ADD )
			nouveau.setEnabled(!etat);
		else if( composant == barJPanel.BUTTON_REMOVE )
			remove.setEnabled(!etat);
		else if( composant == barJPanel.BUTTON_CLEAR )
			vider.setEnabled(!etat);
		else if( composant == barJPanel.BUTTON_COMPRESS )
			comp.setEnabled(!etat);
		else if( composant == barJPanel.BUTTON_UNCOMPRESS )
			decomp.setEnabled(!etat);
		else if( composant == barJPanel.BUTTON_ALL )
		{
			nouveau.setEnabled(!etat);
			remove.setEnabled(!etat);
			vider.setEnabled(!etat);
			comp.setEnabled(!etat);
			decomp.setEnabled(!etat);			
		}	
		bjp.bloquer( composant, etat);
	}
	
	public static void main( String [] args )
	{
		if(args.length >0)
			new LeonMP3Encoder( args );
		else
			new LeonMP3Encoder();		
	}
}